==> estateplat-common-1.1.0-20160803.022340-136-sources.jar: cn/gtmap/estateplat/model/server/core/GdCf.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 过度数据对应的查封信息
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_cf")
public class GdCf implements Serializable {
    @Id
    private String cfid;
    private String cfjg;
    private String cflx;
    private String cfwj;
    private String cfwh;
    private Date cfksrq;
    private Date cfjsrq;
    private String cffw;
    private String bdclx;
    private String proid;
    private Integer isjf;//0 正常 1 注销
//    private String ppzt;
    private String djlx;
    private String fj;
    private Date gxrq;
    private String fysdr; //法院送达人
    private String fysdrlxfs;  //法院送达人联系方式
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private Date  jfrq;//修改日期
    private String jfr;//修改人
    private String bz;//备注

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getJfr() {
        return jfr;
    }

    public void setJfr(String jfr) {
        this.jfr = jfr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getCfid() {
        return cfid;
    }

    public void setCfid(String cfid) {
        this.cfid = cfid;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public Date getCfksrq() {
        return cfksrq;
    }

    public void setCfksrq(Date cfksrq) {
        this.cfksrq = cfksrq;
    }

    public Date getCfjsrq() {
        return cfjsrq;
    }

    public void setCfjsrq(Date cfjsrq) {
        this.cfjsrq = cfjsrq;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }


    public Integer getIsjf() {
        return isjf;
    }

    public void setIsjf(Integer isjf) {
        this.isjf = isjf;
    }


    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getFysdr() {
        return fysdr;
    }

    public void setFysdr(String fysdr) {
        this.fysdr = fysdr;
    }

    public String getFysdrlxfs() {
        return fysdrlxfs;
    }

    public void setFysdrlxfs(String fysdrlxfs) {
        this.fysdrlxfs = fysdrlxfs;
    }
}

==> estateplat-common-1.1.0-20160823.072518-166-sources.jar: cn/gtmap/estateplat/model/server/core/GdCf.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 过度数据对应的查封信息
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_cf")
public class GdCf implements Serializable {
    @Id
    private String cfid;
    private String cfjg;
    private String cflx;
    private String cfwj;
    private String cfwh;
    private Date cfksrq;
    private Date cfjsrq;
    private String cffw;
    private String bdclx;
    private String proid;
    private Integer isjf;//0 正常 1 注销
//    private String ppzt;
    private String djlx;
    private String fj;
    private Date gxrq;
    private String fysdr; //法院送达人
    private String fysdrlxfs;  //法院送达人联系方式
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    private Date  jfrq;//修改日期
    private String jfr;//修改人
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getJfr() {
        return jfr;
    }

    public void setJfr(String jfr) {
        this.jfr = jfr;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getCfid() {
        return cfid;
    }

    public void setCfid(String cfid) {
        this.cfid = cfid;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public Date getCfksrq() {
        return cfksrq;
    }

    public void setCfksrq(Date cfksrq) {
        this.cfksrq = cfksrq;
    }

    public Date getCfjsrq() {
        return cfjsrq;
    }

    public void setCfjsrq(Date cfjsrq) {
        this.cfjsrq = cfjsrq;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }


    public Integer getIsjf() {
        return isjf;
    }

    public void setIsjf(Integer isjf) {
        this.isjf = isjf;
    }


    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getFysdr() {
        return fysdr;
    }

    public void setFysdr(String fysdr) {
        this.fysdr = fysdr;
    }

    public String getFysdrlxfs() {
        return fysdrlxfs;
    }

    public void setFysdrlxfs(String fysdrlxfs) {
        this.fysdrlxfs = fysdrlxfs;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
}
